@@ -20,10 +20,21 @@ class TentacleFactory:
     def __init__(self, tentacle_root_path):
         self.tentacle_root_path = tentacle_root_path
 
-    def create_tentacle_from_type(self, name, tentacle_type):
+    def create_tentacle_from_type(self, name, tentacle_type) -> models.Tentacle:
+        """
+        Create a tentacle artifact from its name and type
+        :param name: the tentacle name
+        :param tentacle_type: the tentacle type
+        :return: the created TentacleArtifact instance
+        """
         return models.Tentacle(self.tentacle_root_path, name, tentacle_type)
 
-    async def create_and_load_tentacle_from_module(self, tentacle_module):
+    async def create_and_load_tentacle_from_module(self, tentacle_module) -> models.Tentacle:
+        """
+        Create and load a tentacle from a tentacle module
+        :param tentacle_module: the tentacle module to use
+        :return: the loaded tentacle instance
+        """
         tentacle_type = models.TentacleType.from_import_path(self.tentacle_root_path, tentacle_module.__name__)
         tentacle = models.Tentacle(self.tentacle_root_path, tentacle_type.module_name, tentacle_type)
         await tentacle.initialize()
